Summary
Functions
Attributes
id(:string) - modal id. Defaults to"modal".hide(:boolean) - modal is hidden. Defaults tofalse.title(:string) - modal title. Defaults tonil.class(:any) - modal class. Defaults tonil.close_modal_target(:string) - close_modal_target allows you to target a specific live component for the close event to go to. eg: close_modal_target={@myself}. Defaults tonil.close_on_click_away(:boolean) - whether the modal should close when a user clicks away. Defaults totrue.close_on_escape(:boolean) - whether the modal should close when a user hits escape. Defaults totrue.hide_close_button(:boolean) - whether or not the modal should have a close button in the header. Defaults tofalse.on_open(Phoenix.LiveView.JS) - additional JS commands to run when the modal opens. Defaults to%Phoenix.LiveView.JS{ops: []}.on_cancel(Phoenix.LiveView.JS) - a JS function to execute when the modal is closed. Defaults to pushing close_modal event. Defaults to%Phoenix.LiveView.JS{ops: [["exec", %{attr: "data-cancel-default"}]]}.max_width(:string) - modal max width. Defaults to"md". Must be one of"sm","md","lg","xl","2xl", or"full".- Global attributes are accepted.
Slots
inner_block